@@ -1,7 +1,5 @@
 LogLik_bounds_est_root <-
 function(tree,trait ,dCoeff,V, x0_pos,bounds){
-if ((bounds[1]>min(trait))|(bounds[2]<max(trait))) {return(-Inf)} # bounds have to be outside the trait interval
-	else {
 Npts_tot=length(V)		
 tree_formatted=FormatTree_bounds(tree,trait,V,bounds)		
 dMat=DiffMat_backwards(V)
@@ -15,6 +13,4 @@ for (i in 1:dim(tree_formatted2$tab)[1]){
 	logFactor=logFactor+log(norm)
 }
 return(log(tree_formatted2$Pos[[tree_formatted2$tab[i,1]]][x0_pos])+logFactor) # extraction of the likelihood for a given root value (in the ML optimization version, we take max(tree_formatted2$Pos[[tree_formatted2$tab[i,1]]]))
-
-	}
 }
